PeView

Struct PeView 

pub struct PeView<'a> { /* private fields */ }
View into a mapped PE image.

Implementations

Source

impl<'a> PeView<'a>

pub fn from_bytes<T: AsRef<[u8]> + ?Sized>(image: &'a T) -> Result<PeView<'a>>

Constructs a view from a byte slice.

Errors
  • Bounds: The byte slice is too small to fit the PE headers.

  • Misaligned: The minimum alignment of 4 is not satisfied.

  • BadMagic: This is not a PE file.

  • PeMagic: Trying to parse a PE32 file with the PE32+ parser and vice versa.

  • Insanity: Reasonable limits on e_lfanew, SizeOfHeaders or NumberOfSections are exceeded.

pub unsafe fn module(base: *const u8) -> PeView<'a>

Constructs a new view from module handle.

Safety

The underlying memory is borrowed and an unbounded lifetime is returned. Ensure the lifetime outlives this view instance!

No sanity or safety checks are done to make sure this is really PE32(+) image. When using this with a HMODULE from the system the caller must be sure this is a PE32(+) image.

pub fn to_file(self) -> Vec<u8>

Converts the view to file alignment.