Ptr

Struct Ptr 

pub struct Ptr<T: ?Sized = ()> { /* private fields */ }
Typed virtual address.

Implementations

Source

impl<T: ?Sized> Ptr<T>

pub const NULL: Ptr<T>

Null pointer constant.

pub const fn null() -> Ptr<T>

Creates a null pointer.

pub const fn is_null(self) -> bool

Returns true if the pointer is null.

pub const fn member(va: Va, offset: u32) -> Ptr<T>

Constructs a pointer with an offset.

pub const fn cast<U: ?Sized>(self) -> Ptr<U>

Casts the pointer to a different type keeping the pointer address fixed.

pub const fn offset<U: ?Sized>(self, offset: i32) -> Ptr<U>

Offsets and casts the pointer.

Because the type of the current and the target may be unrelated, this is a byte offset.

Examples
use pelite::pe64::Ptr;

#[repr(C)]
struct Composite {
	int: i32,
	float: f32,
}

let p: Ptr<Composite> = Ptr::from(0x2000);
let target = p.offset::<f32>(4);

assert_eq!(target, Ptr::from(0x2004));
pub const fn into_raw(self) -> Va

Returns the raw integer, type ascription helper.

Source

impl<T> Ptr<[T]>

pub const fn decay(self) -> Ptr<T>

Decays the pointer from [T] to T.

pub const fn at(self, i: usize) -> Ptr<T>

Pointer arithmetic, gets the pointer of an element at the specified index.